(function() {
  var config, connectESI, express, fs, pantry;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  express = require('express');
  pantry = require('pantry');
  fs = require('fs');
  connectESI = require('connect-esi');
  config = {
    appName: "Timbits",
    engine: "coffee",
    port: 5678,
    home: process.cwd()
  };
  this.serve = function(options) {
    var key, path, value;
    for (key in options) {
      value = options[key];
      config[key] = value;
    }
    this.server = express.createServer();
    this.server.register('.coffee', require('coffeekup'));
    this.server.set('views', "" + config.home + "/views");
    this.server.set('view engine', config.engine);
    this.server.set('view options', {
      layout: false
    });
    this.server.configure(__bind(function() {
      this.server.use(connectESI.setupESI());
      this.server.use(express.static("" + config.home + "/public"));
      this.server.use(express.bodyParser());
      return this.server.use(express.cookieParser());
    }, this));
    this.server.configure('development', __bind(function() {
      return this.server.use(express.errorHandler({
        dumpExceptions: true,
        showStack: true
      }));
    }, this));
    this.server.configure('production', __bind(function() {
      return this.server.use(express.errorHandler());
    }, this));
    this.server.get('/', function(req, res) {
      return res.render('help');
    });
    path = "" + config.home + "/timbits";
    fs.readdir(path, __bind(function(err, files) {
      var file, name, _i, _len, _results;
      if (err) {
        throw err;
      }
      _results = [];
      for (_i = 0, _len = files.length; _i < _len; _i++) {
        file = files[_i];
        name = file.replace('.coffee', '');
        _results.push(this.add(name, require("" + path + "/" + name)));
      }
      return _results;
    }, this));
    this.server.listen(process.env.PORT || config.port);
    console.log("Timbits server listening on port " + (this.server.address().port) + " in " + this.server.settings.env + " mode");
    return this.server;
  };
  this.box = {};
  this.add = function(name, timbit) {
    console.log("\t Placing " + name + " in the box");
    timbit.name = name;
    this.box[name] = timbit;
    return this.server.get(timbit.route || ("/" + name + "/:view?"), function(req, res) {
      var context, _base, _ref;
      context = {
        name: name,
        view: (_ref = (_base = req.params).view) != null ? _ref : _base.view = 'default',
        request: req,
        response: res
      };
      return timbit.eat(context);
    });
  };
  this.Timbit = (function() {
    function Timbit() {}
    Timbit.prototype.render = function(context) {
      return context.response.render("" + context.name + "/" + context.view, {
        context: context
      });
    };
    Timbit.prototype.fetch = function(context, key, options, callback) {
      if (callback == null) {
        callback = this.render;
      }
      return pantry.fetch(options, __bind(function(error, results) {
        context[key] = results;
        return callback(context);
      }, this));
    };
    Timbit.prototype.eat = function(context) {
      return this.render(context);
    };
    return Timbit;
  })();
}).call(this);
